@@ -13,7 +13,7 @@
 #include "../include/generic.h"
 
 
-int get_os_info(os_info_t *os_info) {
+int get_os_info(struct os_info_type *os_info) {
    return uname_get_os_info(os_info);
 }
 
@@ -34,7 +34,7 @@ void get_load_average(float *load_1,float *load_5,float *load_15) {
 }
 
 
-char *get_host_name(char hostname[65],char domain[65]) {
+char *get_host_name(char *hostname,char *domain) {
        return uname_get_host_name(hostname,domain);
 }
 
@@ -49,7 +49,7 @@ long int get_mem_size(void) {
    return size;
 }
 
-int get_cpu_info(cpu_info_t *cpu_info) {
+int get_cpu_info(struct cpu_info_type *cpu_info) {
 
    FILE *fff;
    
@@ -60,7 +60,7 @@ int get_cpu_info(cpu_info_t *cpu_info) {
    
    /* Cpu: MIPS R12000 */
    fff=popen("hinv -t cpu","r");
-   fscanf(fff,"%*s %s %s",cpu_info->chip_vendor,cpu_info->chip_type);
+   fscanf(fff,"%*s %32s %64s",cpu_info->chip_vendor,cpu_info->chip_type);
    pclose(fff);
 
    cpu_info->bogomips=external_bogomips();
