@@ -12,29 +12,28 @@
 
 
 
-int get_cpu_info(cpu_info_t *cpu_info) {
+int get_cpu_info(struct cpu_info_type *cpu_info) {
 
     FILE *fff;
-    char temp_string[256];
-    char vendor_string[256],model_string[256],hardware_string[256];
+    char temp_string[BUFSIZ],temp[BUFSIZ];
+    char vendor_string[BUFSIZ],model_string[BUFSIZ];
     int cpu_count=0;
     float megahertz=0.0,bogomips=0.0;
    
-    vendor_string[0]=model_string[0]=hardware_string[0]=0;
+    vendor_string[0]=model_string[0]=0;
  
        /* We get all of our info here from /proc/cpuinfo */
     if ((fff=fopen(get_cpuinfo_file(),"r") )!=NULL) {
        
-       while ( (fgets(temp_string,255,fff)!=NULL) ) {
+       while ( (fgets(temp_string,BUFSIZ,fff)!=NULL) ) {
 	
 	  if ( !(strncmp(temp_string,"cpu",3))) {
-	     strncpy(model_string,parse_line(temp_string),256);  
-	     clip_lf(model_string,255);
+	     strncpy(model_string,parse_line(temp_string),BUFSIZ);
+	     clip_lf(model_string,BUFSIZ);
 	  }
 
 	  if ( !(strncmp(temp_string,"ncpus active",12))) {
-	     cpu_count=atoi(parse_line(temp_string));
-	     
+	     cpu_count=atoi(parse_line(temp_string));	     
 	  }
 	  
 	     /* Suggested change by Ben Collins <bmc@visi.net> */
@@ -54,24 +53,27 @@ int get_cpu_info(cpu_info_t *cpu_info) {
        }
     }
   
-    strncpy(cpu_info->chip_vendor,"Sparc",32);
-    strncpy(cpu_info->chip_type,model_string,63);
+    strncpy(cpu_info->chip_vendor,"Sparc",SYSINFO_CHIP_VENDOR_SIZE);
+    strncpy(cpu_info->chip_type,model_string,SYSINFO_CHIP_TYPE_SIZE);
   
        /* Fix up cpuinfo some */
    
     if (!strncmp(model_string,"Cypress",7)) {
        strncpy(cpu_info->chip_vendor,"Cypress",8);
-       sscanf(model_string,"%*s %s",cpu_info->chip_type);
+       sscanf(model_string,"%*s %s",temp);
+       strncpy(cpu_info->chip_type,temp,SYSINFO_CHIP_TYPE_SIZE);
     }
    
     if (!strncmp(model_string,"ROSS",4)) {
        strncpy(cpu_info->chip_vendor,"ROSS",5);
-       sscanf(model_string,"%*s %s",cpu_info->chip_type);
+       sscanf(model_string,"%*s %s",temp);
+       strncpy(cpu_info->chip_type,temp,SYSINFO_CHIP_TYPE_SIZE);
     }
    
     if (!strncmp(model_string,"Texas",5)) {
        strncpy(cpu_info->chip_vendor,"TI",3);
-       sscanf(model_string,"%*s %*s %*s %*s %s",cpu_info->chip_type);
+       sscanf(model_string,"%*s %*s %*s %*s %s",temp);
+       strncpy(cpu_info->chip_type,temp,SYSINFO_CHIP_TYPE_SIZE);
        
        if (strstr(model_string,"UltraSparc II ")!=NULL) {
 	  strncpy(cpu_info->chip_type,"UltraSparc II",14);  
@@ -102,19 +104,19 @@ int get_cpu_info(cpu_info_t *cpu_info) {
    
 }
 
-int get_hardware(char hardware_string[65]) {
+int get_hardware(char *hardware_string) {
     
-    char temp_string[256];
+    char temp_string[BUFSIZ];
     FILE *fff;
    
     if ((fff=fopen(get_cpuinfo_file(),"r") )!=NULL) {
        
-       while ( (fgets(temp_string,255,fff)!=NULL) ) {
+       while ( (fgets(temp_string,BUFSIZ,fff)!=NULL) ) {
 	  	  
 	  if (!(strncmp(temp_string,"type",4))) {
-             strncpy(hardware_string,parse_line(temp_string),64);
+             strncpy(hardware_string,parse_line(temp_string),
+		     SYSINFO_HARDWARE_STRING_SIZE);
 	  }
-
        }
     }
     return 1;
